@@ -212,13 +212,30 @@
                         return;
                     }
 
-                    if (item.models) {
-                        item.models.forEach(child => {
-                            self.models.push(child);
-                        });
-                    } else {
-                        self.models.push(item);
+                    let models = [];
+
+                    function deep(menus) {
+                        menus.forEach(item => {
+                            //这是首页，不显示
+                            if (item.eid === "1") {
+                                return;
+                            }
+
+                            if (item.models) {
+                                deep(item.models);
+                            } else {
+                                //没有子级的时候，才加入到首页菜单中去
+                                models.push(item);
+                            }
+
+                        })
+
                     }
+
+                    deep(newValue);
+
+                    self.models = models;
+
                 });
             }
             /*,
@@ -309,7 +326,7 @@
                         item.models.forEach(mItem => {
                             mItem.icon = getIcon(mItem.name, mItem.icon);
                             self.menuData.push(mItem)
-                            if(mItem.models){
+                            if (mItem.models) {
                                 self.handlerMenus(mItem.models);
                             }
                         });
